@@ -106,7 +106,7 @@ if plat == 'Linux' and platform.machine() == "aarch64": # this is jetson nano fo
     from camera.capture.nanocapture import nanoCapture
     camera = nanoCapture(configs, camera_index)
 else:
-    from camera.capture.cv2capture_process import cv2Capture
+    from camera.capture.cv2capture import cv2Capture
     camera = cv2Capture(configs, camera_index)
 
 logger.log(logging.INFO, "Getting Images")
